@@ -1,5 +1,3 @@
-package org.apache.maven.execution;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.execution;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.execution;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.execution;
 
 import org.apache.maven.artifact.versioning.ArtifactVersion;
 
@@ -28,7 +27,6 @@ import org.apache.maven.artifact.versioning.ArtifactVersion;
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
  */
 @Deprecated
-public interface RuntimeInformation
-{
+public interface RuntimeInformation {
     ArtifactVersion getApplicationVersion();
 }
