@@ -1,5 +1,3 @@
-package org.apache.maven.profiles;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.profiles;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,20 +16,19 @@ package org.apache.maven.profiles;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
+package org.apache.maven.profiles;
 
 import java.io.File;
 import java.io.IOException;
 
+import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
+
 /**
  * @author jdcasey
  */
 @Deprecated
-public interface MavenProfilesBuilder
-{
+public interface MavenProfilesBuilder {
     String ROLE = MavenProfilesBuilder.class.getName();
 
-    ProfilesRoot buildProfiles( File basedir )
-        throws IOException, XmlPullParserException;
+    ProfilesRoot buildProfiles(File basedir) throws IOException, XmlPullParserException;
 }
