@@ -1,5 +1,3 @@
-package org.apache.maven.repository.legacy;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.repository.legacy;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.repository.legacy;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.repository.legacy;
 
 import org.apache.maven.wagon.providers.file.FileWagon;
 
@@ -26,9 +25,7 @@ import org.apache.maven.wagon.providers.file.FileWagon;
  *
  * @author <a href="mailto:carlos@apache.org">Carlos Sanchez</a>
  */
-public class WagonMock
-    extends FileWagon
-{
+public class WagonMock extends FileWagon {
 
     /**
      * A field that can be configured in the Wagon
@@ -37,14 +34,11 @@ public class WagonMock
      */
     private String configurableField = null;
 
-    public void setConfigurableField( String configurableField )
-    {
+    public void setConfigurableField(String configurableField) {
         this.configurableField = configurableField;
     }
 
-    public String getConfigurableField()
-    {
+    public String getConfigurableField() {
         return configurableField;
     }
-
 }
