@@ -1,5 +1,3 @@
-package org.apache.maven;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven;
 
 import org.apache.maven.execution.MavenExecutionRequest;
 import org.apache.maven.execution.MavenExecutionResult;
@@ -28,11 +27,10 @@ import org.apache.maven.execution.MavenExecutionResult;
  * @author Jason van Zyl
  * @see org.apache.maven.execution.MavenSession
  */
-public interface Maven
-{
+public interface Maven {
     @Deprecated
-    @SuppressWarnings( "checkstyle:constantname" )
+    @SuppressWarnings("checkstyle:constantname")
     String POMv4 = "pom.xml";
 
-    MavenExecutionResult execute( MavenExecutionRequest request );
-}
\ No newline at end of file
+    MavenExecutionResult execute(MavenExecutionRequest request);
+}
