@@ -1,5 +1,3 @@
-package org.apache.maven.plugin.version;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugin.version;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,33 +16,28 @@ package org.apache.maven.plugin.version;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugin.version;
 
 /**
  * PluginVersionNotFoundException
  */
-public class PluginVersionNotFoundException
-    extends Exception
-{
+public class PluginVersionNotFoundException extends Exception {
     private final String groupId;
 
     private final String artifactId;
 
-    public PluginVersionNotFoundException( String groupId, String artifactId )
-    {
-        super( "The plugin \'" + groupId + ":" + artifactId + "\' does not exist or no valid version could be found" );
+    public PluginVersionNotFoundException(String groupId, String artifactId) {
+        super("The plugin \'" + groupId + ":" + artifactId + "\' does not exist or no valid version could be found");
 
         this.groupId = groupId;
         this.artifactId = artifactId;
     }
 
-    public String getGroupId()
-    {
+    public String getGroupId() {
         return groupId;
     }
 
-    public String getArtifactId()
-    {
+    public String getArtifactId() {
         return artifactId;
     }
-
 }
