@@ -1,5 +1,3 @@
-package org.apache.maven.project;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.project;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.project;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.project;
 
 import java.util.ArrayList;
 import java.util.Date;
@@ -34,9 +33,7 @@ import org.eclipse.aether.RepositorySystemSession;
 /**
  * DefaultProjectBuildingRequest
  */
-public class DefaultProjectBuildingRequest
-    implements ProjectBuildingRequest
-{
+public class DefaultProjectBuildingRequest implements ProjectBuildingRequest {
 
     private RepositorySystemSession repositorySession;
 
@@ -71,8 +68,7 @@ public class DefaultProjectBuildingRequest
 
     private RepositoryMerging repositoryMerging = RepositoryMerging.POM_DOMINANT;
 
-    public DefaultProjectBuildingRequest()
-    {
+    public DefaultProjectBuildingRequest() {
         processPlugins = true;
         profiles = new ArrayList<>();
         activeProfileIds = new ArrayList<>();
@@ -83,144 +79,115 @@ public class DefaultProjectBuildingRequest
         pluginArtifactRepositories = new ArrayList<>();
     }
 
-    public DefaultProjectBuildingRequest( ProjectBuildingRequest request )
-    {
+    public DefaultProjectBuildingRequest(ProjectBuildingRequest request) {
         this();
-        setProcessPlugins( request.isProcessPlugins() );
-        setProfiles( request.getProfiles() );
-        setActiveProfileIds( request.getActiveProfileIds() );
-        setInactiveProfileIds( request.getInactiveProfileIds() );
-        setSystemProperties( request.getSystemProperties() );
-        setUserProperties( request.getUserProperties() );
-        setRemoteRepositories( request.getRemoteRepositories() );
-        setPluginArtifactRepositories( request.getPluginArtifactRepositories() );
-        setRepositorySession( request.getRepositorySession() );
-        setLocalRepository( request.getLocalRepository() );
-        setBuildStartTime( request.getBuildStartTime() );
-        setProject( request.getProject() );
-        setResolveDependencies( request.isResolveDependencies() );
-        setValidationLevel( request.getValidationLevel() );
-        setResolveVersionRanges( request.isResolveVersionRanges() );
-        setRepositoryMerging( request.getRepositoryMerging() );
+        setProcessPlugins(request.isProcessPlugins());
+        setProfiles(request.getProfiles());
+        setActiveProfileIds(request.getActiveProfileIds());
+        setInactiveProfileIds(request.getInactiveProfileIds());
+        setSystemProperties(request.getSystemProperties());
+        setUserProperties(request.getUserProperties());
+        setRemoteRepositories(request.getRemoteRepositories());
+        setPluginArtifactRepositories(request.getPluginArtifactRepositories());
+        setRepositorySession(request.getRepositorySession());
+        setLocalRepository(request.getLocalRepository());
+        setBuildStartTime(request.getBuildStartTime());
+        setProject(request.getProject());
+        setResolveDependencies(request.isResolveDependencies());
+        setValidationLevel(request.getValidationLevel());
+        setResolveVersionRanges(request.isResolveVersionRanges());
+        setRepositoryMerging(request.getRepositoryMerging());
     }
 
-    public MavenProject getProject()
-    {
+    public MavenProject getProject() {
         return project;
     }
 
-    public void setProject( MavenProject mavenProject )
-    {
+    public void setProject(MavenProject mavenProject) {
         this.project = mavenProject;
     }
 
-    public ProjectBuildingRequest setLocalRepository( ArtifactRepository localRepository )
-    {
+    public ProjectBuildingRequest setLocalRepository(ArtifactRepository localRepository) {
         this.localRepository = localRepository;
         return this;
     }
 
-    public ArtifactRepository getLocalRepository()
-    {
+    public ArtifactRepository getLocalRepository() {
         return localRepository;
     }
 
-    public List<ArtifactRepository> getRemoteRepositories()
-    {
+    public List<ArtifactRepository> getRemoteRepositories() {
         return remoteRepositories;
     }
 
-    public ProjectBuildingRequest setRemoteRepositories( List<ArtifactRepository> remoteRepositories )
-    {
-        if ( remoteRepositories != null )
-        {
-            this.remoteRepositories = new ArrayList<>( remoteRepositories );
-        }
-        else
-        {
+    public ProjectBuildingRequest setRemoteRepositories(List<ArtifactRepository> remoteRepositories) {
+        if (remoteRepositories != null) {
+            this.remoteRepositories = new ArrayList<>(remoteRepositories);
+        } else {
             this.remoteRepositories.clear();
         }
 
         return this;
     }
 
-    public List<ArtifactRepository> getPluginArtifactRepositories()
-    {
+    public List<ArtifactRepository> getPluginArtifactRepositories() {
         return pluginArtifactRepositories;
     }
 
-    public ProjectBuildingRequest setPluginArtifactRepositories( List<ArtifactRepository> pluginArtifactRepositories )
-    {
-        if ( pluginArtifactRepositories != null )
-        {
-            this.pluginArtifactRepositories = new ArrayList<>( pluginArtifactRepositories );
-        }
-        else
-        {
+    public ProjectBuildingRequest setPluginArtifactRepositories(List<ArtifactRepository> pluginArtifactRepositories) {
+        if (pluginArtifactRepositories != null) {
+            this.pluginArtifactRepositories = new ArrayList<>(pluginArtifactRepositories);
+        } else {
             this.pluginArtifactRepositories.clear();
         }
 
         return this;
     }
 
-    public Properties getSystemProperties()
-    {
+    public Properties getSystemProperties() {
         return systemProperties;
     }
 
-    public ProjectBuildingRequest setSystemProperties( Properties systemProperties )
-    {
-        if ( systemProperties != null )
-        {
-            this.systemProperties = SystemProperties.copyProperties( systemProperties );
-        }
-        else
-        {
+    public ProjectBuildingRequest setSystemProperties(Properties systemProperties) {
+        if (systemProperties != null) {
+            this.systemProperties = SystemProperties.copyProperties(systemProperties);
+        } else {
             this.systemProperties.clear();
         }
 
         return this;
     }
 
-    public Properties getUserProperties()
-    {
+    public Properties getUserProperties() {
         return userProperties;
     }
 
-    public ProjectBuildingRequest setUserProperties( Properties userProperties )
-    {
-        if ( userProperties != null )
-        {
+    public ProjectBuildingRequest setUserProperties(Properties userProperties) {
+        if (userProperties != null) {
             this.userProperties = new Properties();
-            this.userProperties.putAll( userProperties );
-        }
-        else
-        {
+            this.userProperties.putAll(userProperties);
+        } else {
             this.userProperties.clear();
         }
 
         return this;
     }
 
-    public boolean isProcessPlugins()
-    {
+    public boolean isProcessPlugins() {
         return processPlugins;
     }
 
-    public ProjectBuildingRequest setProcessPlugins( boolean processPlugins )
-    {
+    public ProjectBuildingRequest setProcessPlugins(boolean processPlugins) {
         this.processPlugins = processPlugins;
         return this;
     }
 
-    public ProjectBuildingRequest setResolveDependencies( boolean resolveDependencies )
-    {
+    public ProjectBuildingRequest setResolveDependencies(boolean resolveDependencies) {
         this.resolveDependencies = resolveDependencies;
         return this;
     }
 
-    public boolean isResolveDependencies()
-    {
+    public boolean isResolveDependencies() {
         return resolveDependencies;
     }
 
@@ -230,8 +197,7 @@ public class DefaultProjectBuildingRequest
      * Commit 6cf9320942c34bc68205425ab696b1712ace9ba4 updated the way 'MavenProject' objects are initialized.
      */
     @Deprecated
-    public ProjectBuildingRequest setResolveVersionRanges( boolean value )
-    {
+    public ProjectBuildingRequest setResolveVersionRanges(boolean value) {
         this.resolveVersionRanges = value;
         return this;
     }
@@ -242,108 +208,82 @@ public class DefaultProjectBuildingRequest
      * Commit 6cf9320942c34bc68205425ab696b1712ace9ba4 updated the way 'MavenProject' objects are initialized.
      */
     @Deprecated
-    public boolean isResolveVersionRanges()
-    {
+    public boolean isResolveVersionRanges() {
         return this.resolveVersionRanges;
     }
 
-    public ProjectBuildingRequest setValidationLevel( int validationLevel )
-    {
+    public ProjectBuildingRequest setValidationLevel(int validationLevel) {
         this.validationLevel = validationLevel;
         return this;
     }
 
-    public int getValidationLevel()
-    {
+    public int getValidationLevel() {
         return validationLevel;
     }
 
-    public List<String> getActiveProfileIds()
-    {
+    public List<String> getActiveProfileIds() {
         return activeProfileIds;
     }
 
-    public void setActiveProfileIds( List<String> activeProfileIds )
-    {
-        if ( activeProfileIds != null )
-        {
-            this.activeProfileIds = new ArrayList<>( activeProfileIds );
-        }
-        else
-        {
+    public void setActiveProfileIds(List<String> activeProfileIds) {
+        if (activeProfileIds != null) {
+            this.activeProfileIds = new ArrayList<>(activeProfileIds);
+        } else {
             this.activeProfileIds.clear();
         }
     }
 
-    public List<String> getInactiveProfileIds()
-    {
+    public List<String> getInactiveProfileIds() {
         return inactiveProfileIds;
     }
 
-    public void setInactiveProfileIds( List<String> inactiveProfileIds )
-    {
-        if ( inactiveProfileIds != null )
-        {
-            this.inactiveProfileIds = new ArrayList<>( inactiveProfileIds );
-        }
-        else
-        {
+    public void setInactiveProfileIds(List<String> inactiveProfileIds) {
+        if (inactiveProfileIds != null) {
+            this.inactiveProfileIds = new ArrayList<>(inactiveProfileIds);
+        } else {
             this.inactiveProfileIds.clear();
         }
     }
 
-    public void setProfiles( List<Profile> profiles )
-    {
-        if ( profiles != null )
-        {
-            this.profiles = new ArrayList<>( profiles );
-        }
-        else
-        {
+    public void setProfiles(List<Profile> profiles) {
+        if (profiles != null) {
+            this.profiles = new ArrayList<>(profiles);
+        } else {
             this.profiles.clear();
         }
     }
 
-    public void addProfile( Profile profile )
-    {
-        profiles.add( profile );
+    public void addProfile(Profile profile) {
+        profiles.add(profile);
     }
 
-    public List<Profile> getProfiles()
-    {
+    public List<Profile> getProfiles() {
         return profiles;
     }
 
-    public Date getBuildStartTime()
-    {
+    public Date getBuildStartTime() {
         return buildStartTime;
     }
 
-    public void setBuildStartTime( Date buildStartTime )
-    {
+    public void setBuildStartTime(Date buildStartTime) {
         this.buildStartTime = buildStartTime;
     }
 
-    public RepositorySystemSession getRepositorySession()
-    {
+    public RepositorySystemSession getRepositorySession() {
         return repositorySession;
     }
 
-    public DefaultProjectBuildingRequest setRepositorySession( RepositorySystemSession repositorySession )
-    {
+    public DefaultProjectBuildingRequest setRepositorySession(RepositorySystemSession repositorySession) {
         this.repositorySession = repositorySession;
         return this;
     }
 
-    public DefaultProjectBuildingRequest setRepositoryMerging( RepositoryMerging repositoryMerging )
-    {
-        this.repositoryMerging = Objects.requireNonNull( repositoryMerging, "repositoryMerging cannot be null" );
+    public DefaultProjectBuildingRequest setRepositoryMerging(RepositoryMerging repositoryMerging) {
+        this.repositoryMerging = Objects.requireNonNull(repositoryMerging, "repositoryMerging cannot be null");
         return this;
     }
 
-    public RepositoryMerging getRepositoryMerging()
-    {
+    public RepositoryMerging getRepositoryMerging() {
         return repositoryMerging;
     }
-
 }
