@@ -1,5 +1,3 @@
-package org.apache.maven.model.locator;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,25 +16,24 @@ package org.apache.maven.model.locator;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.model.locator;
+
+import javax.inject.Named;
+import javax.inject.Singleton;
 
 import java.io.File;
 
-import org.codehaus.plexus.component.annotations.Component;
-
 /**
  * Locates a POM file within a project base directory.
  *
  * @author Benjamin Bentmann
  */
-@Component( role = ModelLocator.class )
-public class DefaultModelLocator
-    implements ModelLocator
-{
+@Named
+@Singleton
+public class DefaultModelLocator implements ModelLocator {
 
     @Override
-    public File locatePom( File projectDirectory )
-    {
-        return new File( projectDirectory, "pom.xml" );
+    public File locatePom(File projectDirectory) {
+        return new File(projectDirectory, "pom.xml");
     }
-
 }
